@@ -24,6 +24,8 @@
 |![Typescript Logo](https://docs.aws.amazon.com/cdk/api/latest/img/typescript32.png) Typescript|`@aws-solutions-constructs/aws-route53-alb`|
 |![Java Logo](https://docs.aws.amazon.com/cdk/api/latest/img/java32.png) Java|`software.amazon.awsconstructs.services.route53alb`|
 
+## Overview
+
 This AWS Solutions Construct implements an Amazon Route53 Hosted Zone routing to an Application Load Balancer
 
 Here is a minimal deployable pattern definition:
@@ -133,7 +135,7 @@ Out of the box implementation of the Construct without any override will set the
 
 ### Application Load Balancer
 
-* Creates an Application Load Balancer with no Listener or target. The consruct can incorporate an existing, fully configured ALB if provided.
+* Creates an Application Load Balancer with no Listener or target. The construct can incorporate an existing, fully configured ALB if provided.
 
 ## Architecture
 
@@ -154,6 +156,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_ec2
@@ -178,14 +182,14 @@ class Route53ToAlb(
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
         private_hosted_zone_props: typing.Any = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
@@ -203,6 +207,10 @@ class Route53ToAlb(
         :access: public
         :summary: Constructs a new instance of the Route53ToAlb class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Route53ToAlb.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = Route53ToAlbProps(
             public_api=public_api,
             alb_logging_bucket_props=alb_logging_bucket_props,
@@ -255,14 +263,14 @@ class Route53ToAlbProps:
         self,
         *,
         public_api: builtins.bool,
-        alb_logging_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+        alb_logging_bucket_props: typing.Optional[typing.Union[aws_cdk.aws_s3.BucketProps, typing.Dict[str, typing.Any]]] = None,
         existing_hosted_zone_interface: typing.Optional[aws_cdk.aws_route53.IHostedZone] = None,
         existing_load_balancer_obj: typing.Optional[aws_cdk.aws_elasticloadbalancingv2.ApplicationLoadBalancer] = None,
         existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
         load_balancer_props: typing.Any = None,
         log_alb_access_logs: typing.Optional[builtins.bool] = None,
         private_hosted_zone_props: typing.Any = None,
-        vpc_props: typing.Optional[aws_cdk.aws_ec2.VpcProps] = None,
+        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
     ) -> None:
         '''
         :param public_api: Whether to create a public or private API. This value has implications for the VPC, the type of Hosted Zone and the Application Load Balancer Default: - None
@@ -279,6 +287,17 @@ class Route53ToAlbProps:
             alb_logging_bucket_props = aws_cdk.aws_s3.BucketProps(**alb_logging_bucket_props)
         if isinstance(vpc_props, dict):
             vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(Route53ToAlbProps.__init__)
+            check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
+            check_type(argname="argument alb_logging_bucket_props", value=alb_logging_bucket_props, expected_type=type_hints["alb_logging_bucket_props"])
+            check_type(argname="argument existing_hosted_zone_interface", value=existing_hosted_zone_interface, expected_type=type_hints["existing_hosted_zone_interface"])
+            check_type(argname="argument existing_load_balancer_obj", value=existing_load_balancer_obj, expected_type=type_hints["existing_load_balancer_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
+            check_type(argname="argument load_balancer_props", value=load_balancer_props, expected_type=type_hints["load_balancer_props"])
+            check_type(argname="argument log_alb_access_logs", value=log_alb_access_logs, expected_type=type_hints["log_alb_access_logs"])
+            check_type(argname="argument private_hosted_zone_props", value=private_hosted_zone_props, expected_type=type_hints["private_hosted_zone_props"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[str, typing.Any] = {
             "public_api": public_api,
         }
